%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mmnsa-journal.cls, v1.2, 2021/05/29
% 
% This class file enables authors to prepare 
% manuscripts for submission to "Mathematical Modelling and Numerical Simulation with Applications" journal.
%
% 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\ProvidesClass{mmnsa-journal}[2021/05/29, v1.1]

\newif\if@numrefs
\newif\if@alpharefs

%% Options for bibliography style
\DeclareOption{num-refs}{
  \@numrefstrue
  \@alpharefsfalse
}
\DeclareOption{alpha-refs}{
  \@numrefsfalse
  \@alpharefstrue
}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ExecuteOptions{num-refs}
\ProcessOptions\relax
\LoadClass[twoside,onecolumn]{article}

\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{ifpdf}
\RequirePackage{microtype}
\RequirePackage{euler}
\RequirePackage{merriweather}
\renewcommand{\ttdefault}{lmtt}
\RequirePackage{relsize}
\RequirePackage{ragged2e}
\RequirePackage{xcolor}
\RequirePackage{colortbl}
\RequirePackage{graphicx}
\RequirePackage{etoolbox,xpatch}
\RequirePackage{environ}
\RequirePackage{lastpage}
\RequirePackage{rotating}
\RequirePackage{lscape}
\RequirePackage{afterpage}
\RequirePackage[absolute]{textpos}
\RequirePackage{url}
\RequirePackage{newfloat}
\RequirePackage{mdframed}
\RequirePackage{titlesec}
\RequirePackage{amssymb} % For math environment bold format
\RequirePackage{amsmath}

\RequirePackage[colorlinks,citecolor=blue!80,linkcolor=jcolour, urlcolor=blue!80]{hyperref}
\RequirePackage{academicons}

\RequirePackage{scrextend}
\changefontsizes[15pt]{11.5pt}

\RequirePackage{calc}
\RequirePackage{geometry}
\geometry{includefoot,
  hmargin=4pc+6.64pt,
  bottom=2pc+10pt,
  top=5pc+6pt,
  headsep=2pc,
  headheight=17.5pt,
  footnotesep=1pc+6pt,
  columnsep=18pt}
\setlength{\parindent}{12pt}

%\RequirePackage[colorlinks,allcolors=black,urlcolor=blue]{hyperref}

\RequirePackage[noblocks]{authblk}

\def\@ouplogo{oup.pdf}

%\def\@jname{Journal of X}
%\def\@jlogo{example-grid-100x100pt.png}

\newcommand{\jname}[1]{\def\@jname{#1}}
\newcommand{\jlogo}[1]{\def\@jlogo{#1}}

\def\@jyear{20xx}
\def\@jvolume{0}
\def\@jnumber{0}
%\def\@jstartpage{1}

\newcommand{\jyear}[1]{\def\@jyear{#1}}
\newcommand{\jvolume}[1]{\def\@jvolume{#1}}
\newcommand{\jnumber}[1]{\def\@jnumber{#1}}
\newcommand{\jstartpage}[1]{\def\@jstartpage{#1}}

\newcommand{\changeurlcolor}[1]{\hypersetup{urlcolor=#1}} 

\def\@papercat{}
\def\@runningauthor{}
\def\@runningtitle{}
\def\@corraddress{}
\def\@authnotes{}
\colorlet{jcolour}{blue!40}

\newcommand{\runningauthor}[1]{\def\@runningauthor{#1}}
\newcommand{\runningtitle}[1]{\def\@runningtitle{#1}}
\newcommand{\corraddress}[1]{\def\@corraddress{#1}}
\newcommand{\authnote}[1]{\appto{\@authnotes}{#1\par}}
\newcommand{\papercat}[1]{\def\@papercat{#1}}

\newcommand{\journal}[1]{%
  \ifstrequal{#1}{mmnsa}{%
   \jname{Mathematical Modelling and Numerical Simulation with Applications}%
    \jlogo{mmnsa_logo.pdf}%
    \definecolor{jcolour}{RGB}{199, 62, 31}%
  }{}
  %\ifstrequal{#1}{general}{%
%    \jname{Journal of XYZ}%
%    \jlogo{example-grid-100x100pt.png}%
   % \definecolor{jcolour}{RGB}{128,0,0}%
  
}

\RequirePackage[flushmargin,bottom,norule]{footmisc}
\appto{\footnotelayout}{\fontsize{6.5pt}{9.5pt}\selectfont}
\deffootnote{1.5em}{1.5em}{\thefootnotemark\enspace}

\RequirePackage{fancyhdr}
\fancyhf{}
\renewcommand{\headrule}{\color{black!30}\rule{\textwidth}{2pt}}
\fancyhead[LE]{%
  \hspace*{12pt}%
  \fontsize{10pt}{12pt}\selectfont%
  \color{jcolour}%
  \textbf{\thepage}%
  \hspace{1em}\raisebox{-0.5pt}{|}\hspace{1em}%
  \textbf{\textit{\@jname, \@jyear, Vol.~\@jvolume, No.~\@jnumber, \@jstartpage--\pageref{LastPage}}}
}
\fancyhead[RO]{%
  \fontsize{10pt}{12pt}\selectfont%
  \color{jcolour}%
 \textbf{\@runningauthor} %
  \hspace{1em}\raisebox{-0.5pt}{|}\hspace{1em}%
  \textbf{\thepage}%
  \hspace*{12pt}%
}

\fancypagestyle{plain}{%
  \fancyhf{}
  \renewcommand{\headrule}{}
  \fancyfoot[R]{%
    \fontsize{9pt}{10pt}\selectfont%
    \color{jcolour}%
    \textbf{\thepage}\hspace*{12pt}%
  }
}



\pagestyle{fancy}


\AtBeginDocument{%
  \newsavebox{\@mmnsacitedetails}
  \newlength{\@mmnsacitedetailsheight}
  \newsavebox{\@mmnsaheadbox}
  \newlength{\@mmnsaheadboxheight}
  \savebox{\@mmnsacitedetails}{%
    \parbox{\textwidth-23.0pc+4pc+6.64pt}{%
\fontsize{11.3pt}{13.0pt}\bfseries%
{\@jname},
\fontsize{11.3pt}{9.2pt}\bfseries%
%Dergi ismi altındaki çizgi boşluğu
{\@jyear, \@jvolume(\@jnumber), \@jstartpage--\pageref{LastPage}}\par
%     \vspace{\dimexpr 8pt-1em\relax}
    {\color{jcolour}\rule{\linewidth}{1.5pt}}\par
    %jcolor yerine black!15 yazılabilir
    \vspace{\dimexpr 8.5pt-1em\relax}%
    \fontsize{10.0pt}{14.5pt}\bfseries%
    \textcolor{jcolour}{https://dergipark.org.tr/en/pub/mmnsa}\par
    {ISSN Online: 2791-8564  /  Open Access}\par
   Manuscript in Preparation \par
    \textcolor{jcolour}{https://doi.org/10.53391/mmnsa.2021.01.xxx}\par
    %\@papercat\par
    \vspace{\dimexpr 8.0pt-1.5em\relax}%
    {\color{jcolour}\rule{\linewidth}{1.5pt}}\par
  }}%
  \settototalheight{\@mmnsacitedetailsheight}{\usebox{\@mmnsacitedetails}}%
  %%%%
  \savebox{\@mmnsaheadbox}{%
    \parbox{\textwidth-26.5pc+4pc+6.64pt}{%
    \normalfont%
    \fontsize{8pt}{9.5pt}\selectfont%
% {\itshape\bfseries\@jname}, \@jyear, \@jstartpage--\pageref{LastPage}\par
    \vspace{\dimexpr 8pt-1.5pt\relax}%
    \usebox{\@mmnsacitedetails}
    }%
  }%
  \settototalheight{\@mmnsaheadboxheight}{\usebox{\@mmnsaheadbox}}%
}

\RequirePackage{alphalph}
\newalphalph{\fnsymbolmult}[mult]
{\@fnsymbol}{5}

\newcounter{authorfn}
\setcounter{authorfn}{1}
\newcommand{\authfn}[1]{%
  \fnsymbolmult{#1}%
}

\renewcommand\Authands{ \textbf{and} }
\renewcommand\AB@affilsepx{, }
\renewcommand{\Authfont}{\fontsize{14pt}{18pt}\selectfont}
\renewcommand{\Affilfont}{\fontsize{11pt}{15pt}\selectfont}
\setlength{\affilsep}{21pt-9pt}

\AtBeginDocument{
 \renewcommand{\@maketitle}{%
  \textblockorigin{3pc+17.64pt}{4pc+6pt}
    \begin{textblock*}{21pc}(0pt,0pt)
     %\includegraphics[height=\@mmnsaheadboxheight]{\@ouplogo}%
%  }{%
%    \fbox{\begin{minipage}[b][\@mmnsaheadboxheight]{\@mmnsaheadboxheight}
%    \raggedright
%    Placeholder for OUP logo \@ouplogo
 %   \end{minipage}}%
%  }
  \hspace{0pt}%
  %% Do absolutely nothing if \@jlogo is empty string
  \ifdefempty{\@jlogo}{}{%
  \IfFileExists{\@jlogo}{%
    \includegraphics[height=7.8pc, width=7.8pc]{\@jlogo}
  }{%
    \fbox{\begin{minipage}[b][\@mmnsaheadboxheight]{\@mmnsaheadboxheight}%
    \raggedright Placeholder for journal logo \@jlogo
    \end{minipage}}%
  }}
  \end{textblock*}
  %%%
  \begin{textblock*}{\textwidth-21pc}(18.5pc,0pt)
  \usebox{\@mmnsaheadbox}
  \end{textblock*}%
  %%%
  \null\vspace*{\dimexpr 13pc+11pt-4pc-6pt\relax}%
  \raggedright%
  {\fontsize{11pt}{19pt}\selectfont%
    \ifpdf
      \textls[200]{\relsize{-1}\MakeUppercase{\@papercat}}
    \else %%% don't use letterspace in latex+dvi
      \relsize{-1}\MakeUppercase{\@papercat}%
    \fi%
    \par}
  \vspace{\dimexpr 26pt-18pt\relax}
  {\fontsize{18pt}{22pt} 
    \bfseries\color{jcolour}\@title\par}
  \vspace{\dimexpr 26pt-13pt\relax}
  \@author\par
  \vspace{\dimexpr 15.5pt-1em}
  {%
    \renewcommand{\authfn}[1]{%
      \textsuperscript{\fnsymbolmult{##1}}%
    }
    {\fontsize{9.5pt}{11.0pt}\selectfont\@authnotes\par}%
  }
  \vspace{\dimexpr 16pt-3pt-1.2em\relax}
}
}
\RequirePackage[style]{abstract}
\setlength{\absleftindent}{0pt}
\setlength{\absrightindent}{0pt}
\setlength{\parindent}{0pt}
%\setlength{\absparindent}{12pt}
\setlength{\absparsep}{0pt}
\setlength{\abstitleskip}{17pt-7.5pt-\baselineskip}
\renewcommand{\abstractnamefont}{\fontsize{12pt}{13pt}\bfseries\color{jcolour}}
\renewcommand{\abstitlestyle}[1]{{\abstractnamefont #1}}
\renewcommand{\abstracttextfont}{\fontsize{11.0pt}{13pt}\selectfont}
\preto{\abstract}{%
  {\noindent\color{jcolour!60}\rule{433pt+4pc+6.64pt}{3pt}}\par
  \vspace*{\dimexpr 22pt-3pt-1.2em\relax}
}

\appto\abstract{\noindent\ignorespaces}
\preto\endabstract{\par}

\newenvironment{keywords}
{\vspace*{\dimexpr 22pt-8pt-\baselineskip\relax}%
\noindent\fontsize{11pt}{13pt}\selectfont\textbf{Keywords}: \ignorespaces}%
{\par}

\newenvironment{AMS}
{\vspace*{\dimexpr 24pt-5pt-\baselineskip\relax}%
\noindent\fontsize{11pt}{13pt}\selectfont\textbf{AMS 2020 Classification}: \ignorespaces}%
{\par}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\if@twocolumn
  \NewEnviron{frontmatter}
  {\twocolumn[%
      \BODY%
      \vspace*{\dimexpr 16pt-3pt-1em\relax}
      {\noindent\color{jcolour!50}\rule{433pt+4pc+6.64pt}{3pt}}\par
      \vspace*{\dimexpr 23pt-1em\relax}]%
    \begin{figure*}[b!]
      \fontsize{7.5pt}{9.5pt}\selectfont%
      \hrule%
      \vspace{\dimexpr 14pt-6.5pt\relax}%
      \textbf{Compiled on: } \today.\par
      Draft manuscript for peer-review prepared by the authors.\par
    \end{figure*}
  }
\else
  \NewEnviron{frontmatter}{%
      \BODY%
      \vspace*{\dimexpr 16pt-3pt-1em\relax}
      {\noindent\color{jcolour!60}\rule{433pt+4pc+6.64pt}{3pt}}\par
      \vspace*{\dimexpr 10pt-1em\relax}%
    \begin{figure*}[b!]
      \fontsize{9.5pt}{10.5pt}\selectfont%
      \hrule%
      %sol alt yazı boyutu ve satır aralığı
      \vspace{\dimexpr 14pt-6.5pt\relax}%
       \textbf{Compiled on:} \today.\par
      Draft manuscript for peer-review prepared by the authors.\par
       %The following information will be assigned by editors
      % \textbf{\ding{228} Received:} 30.01.2023 \,\ \ding{228} \textbf{Revised:} 15.03.2023 \,\ \ding{228} \textbf{Accepted:} 18.03.2023 \,\ \ding{228} \textbf{Published:} 26.03.2023 \par
    \end{figure*}
  }
\fi


\setcounter{secnumdepth}{1}
\titleformat*{\section}{\fontsize{12.5pt}{16pt}\bfseries\color{jcolour}}
\titlespacing*{\section}{0pt}{17.5pt-1em}{18pt-1em}
\titleformat*{\subsection}{\fontsize{11.5pt}{14pt}\bfseries\color{jcolour}}
\titlespacing*{\subsection}{0pt}{2pc-1em}{17pt-1em}
\titleformat*{\subsubsection}{\fontsize{11pt}{13pt}\bfseries\color{jcolour}}
\titlespacing*{\subsubsection}{0pt}{2pc-1em}{12pt-1em}
\titleformat{\paragraph}[runin]{\normalsize\itshape}{\theparagraph}{0pt}{}[.\enspace]
\titlespacing*{\paragraph}{0pt}{\baselineskip}{0pt}
  \titleformat{\subparagraph}[runin]{\relsize{-1}\uppercase}{\thesubparagraph}{0pt}{}[.\enspace]
\titlespacing*{\subparagraph}{0pt}{\baselineskip}{0pt}

\RequirePackage{enumitem}
\setlist{noitemsep}
\setlist[itemize]{leftmargin=12pt,topsep=16pt-1em}
\setlist[enumerate]
{itemindent=14pt,topsep=16.8pt-1em,
 label={\roman*.},labelsep=7pt,
 labelwidth=*,leftmargin=*,align=right}


% quotes and epigraphs
\RequirePackage{quoting}
\newcommand{\quotefont}{\fontsize{6.5pt}{9.5pt}\selectfont}
\quotingsetup{vskip=16pt-1em,indentfirst=false,font={quotefont},leftmargin=12pt,rightmargin=12pt}

\renewenvironment{quote}{\begin{quoting}}{\end{quoting}}

\renewenvironment{quotation}{\begin{quoting}}{\end{quoting}}

\newenvironment{epigraph}[1]
{\begin{quoting}[font={itshape,fontsize{7.5pt}{10.5pt}},vskip=15pt-1em,leftmargin=0pt,rightmargin=0pt]%
 \def\@quotesource{#1}}
{\par\vspace{\dimexpr 15pt-1em\relax}{\upshape---\@quotesource}\end{quoting}}

% Space above/below equations
\g@addto@macro\normalsize{%
  \setlength\abovedisplayskip{\baselineskip}%
  \setlength\belowdisplayskip{\baselineskip}%
  \setlength\abovedisplayshortskip{\baselineskip}%
  \setlength\belowdisplayshortskip{\baselineskip}%
}

\RequirePackage{stfloats}
\RequirePackage{booktabs}
\RequirePackage{tabularx}
% Left-, right- and center-aligned auto-wrapping column types
\newcolumntype{L}{>{\raggedright\arraybackslash}X}
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}
\newcolumntype{C}{>{\centering\arraybackslash}X}

\AtBeginEnvironment{tabularx}{%
  \fontsize{10pt}{13pt}\selectfont
}
\AtBeginEnvironment{tabular}{%
  \fontsize{10pt}{13pt}\selectfont
}

\setlength{\aboverulesep}{12pt-1em}
\setlength{\belowrulesep}{12pt-1em}
\setlength{\heavyrulewidth}{0.5pt}
\setlength{\lightrulewidth}{0.5pt}
\arrayrulecolor{jcolour}


\newcommand{\tnote}[1]{\textsuperscript{\textit{#1}}}
\newlist{tablenotes}{itemize}{1}
\setlist[tablenotes]{label={},labelsep=0pt,leftmargin=0pt,topsep={\dimexpr 11pt-1em\relax}}
\appto{\tablenotes}{\fontsize{8.7pt}{15pt}\selectfont}

\RequirePackage[tableposition=top]{caption}
\DeclareCaptionFont{figcaptionfont}{\fontsize{10pt}{13pt}\selectfont}
\DeclareCaptionFont{tabcaptionfont}{\fontsize{10pt}{13pt}\selectfont}
\captionsetup{justification=justified,singlelinecheck=false,labelfont={bf},labelsep=period}
\captionsetup*[figure]{font=figcaptionfont,skip=10pt}
\captionsetup*[table]{font=tabcaptionfont,skip=15pt-1em}

% Skips for floats
\setlength{\floatsep}{1pc+6pt}
\setlength{\intextsep}{1pc+6pt}
\setlength{\textfloatsep}{1pc+6pt}




% References
\if@numrefs
  \RequirePackage[numbers]{natbib}
  \bibliographystyle{vancouver-authoryear}
\fi
\if@alpharefs
    \RequirePackage{natbib}
    \bibliographystyle{dcu}
\fi
\setlength{\bibhang}{5pt}
\setlength{\bibsep}{4pt}
\renewcommand{\bibnumfmt}[1]{[#1]}



% References

%\if@numrefs
%  \RequirePackage[square,numbers]{natbib}
%   \bibliographystyle{vancouver-authoryear}
%\fi


%\if@alpharefs
%    \RequirePackage{natbib}
%    \bibliographystyle{dcu}
%\fi

%\setlength{\bibhang}{11pt}
%\setlength{\bibsep}{0pt}
%\renewcommand{\bibnumfmt}[1]{[#1]}


%\renewcommand*{\bibnumfmt}[1]{\noindent[#1]}
%\setlength{\itemsep}{0pt}
%\renewcommand\@biblabel[1]{[#1]}
%\renewcommand{\bibnumfmt}[1]{#1.}